# APP_NAME_PLACEHOLDER

My new awesome homebrew application for the Nintendo Switch, created with 
[libtransistor](https://github.com/reswitched/libtransistor).

[![generated_by nxstart](https://img.shields.io/badge/generated_by-nxstart-blue.svg)](https://github.com/roedesh/nxstart)

## Features

...

## Getting Started

Download the [latest release of libtransistor](https://github.com/reswitched/libtransistor/releases/latest) 
and extract it. The recommended place to extract these archives is into `/opt/libtransistor/`. Next, set the 
`LIBTRANSISTOR_HOME` environment variable to wherever you extracted the archive.

### Running the app

Run `make` inside this folder. Put the `.nro` file you just created on your SD card and launch it.

## Author

APP_AUTHOR_PLACEHOLDER
